@@ -386,7 +386,7 @@ END
          '"install","HTTP::Server::Simple")\'',
          '__display__');
    }
-      $show=<<END;
+   my $show=<<END;
 ########################################
 
    INSTALLING Perl::Critic
@@ -398,7 +398,6 @@ END
          'perl -MCPAN -e \'CPAN::Shell->notest('.
          '"install","Perl::Critic")\'',
          '__display__');
-   }
    my $show=<<END;
 ########################################
 
@@ -496,6 +495,7 @@ END
       Parallel::Forker
       UUID::Tiny
       Regexp::Assemble
+      Crypt::PassGen
 
    );
    my $install_chaining=<<'END';
@@ -742,6 +742,42 @@ END
            '__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING Method::Signatures::Simple
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Method::Signatures::Simple",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING HTML::FormHandler
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan HTML::FormHandler",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING HTML::FormHandler::Model::DBIC
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan HTML::FormHandler::Model::DBIC",
+           '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING CatalystX::SimpleLogin
@@ -772,6 +808,7 @@ END
 END
    print $show;
    sleep 1;
+   # http://vasil9v.tumblr.com/post/31921755331/compiling-memcached-on-cygwinwindows
    cmd_raw($handle,"${sudo}cpan Catalyst::Plugin::Session::Store::Memcached",
            '__display__');
    $show=<<END;
@@ -824,6 +861,42 @@ END
            '__display__');
    $show=<<END;
 
+########################################
+
+   INSTALLING DBIx::Class::TimeStamp
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan DBIx::Class::TimeStamp",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::Controller::ACL
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::Controller::ACL",
+           '__display__');
+   $show=<<END;
+
+########################################
+
+   INSTALLING Catalyst::View::Email
+
+########################################
+END
+   print $show;
+   sleep 1;
+   cmd_raw($handle,"${sudo}cpan Catalyst::View::Email",
+           '__display__');
+   $show=<<END;
+
 ########################################
 
    INSTALLING Finance::Quote
@@ -865,20 +938,19 @@ END
    #   }
    #}
    ($stdout,$stderr)=$handle->cwd("..");
-   ($stdout,$stderr)=$handle->cmd("catalyst.pl AdventREST",'__display__');
-   ($stdout,$stderr)=$handle->cwd("AdventREST");
+   ($stdout,$stderr)=$handle->cmd("catalyst.pl FullAutoAPI",'__display__');
+   ($stdout,$stderr)=$handle->cwd("FullAutoAPI");
    ($stdout,$stderr)=$handle->cmd("perl Makefile.PL",'__display__');
-   my $pm_path="./lib/AdventREST.pm";
+   my $pm_path="./lib/FullAutoAPI.pm";
    $ad="    Session%NL%".
        "    Session::Store::Memcached%NL%".
        "    Session::State::Cookie%NL%".
        "    Authentication%NL%".
        "    Authorization::Roles%NL%".
-       "    +CatalystX::SimpleLogin%NL%";
+       "    +CatalystX::SimpleLogin";
    ($stdout,$stderr)=$handle->cmd(
-      "${sudo}sed -i '/Static::Simple$/a$ad' $pm_path");
-   $ad="__PACKAGE__->config(%NL%".
-       "   authentication => {%NL%".
+       "${sudo}sed -i '/    Static::Simple/a$ad' $pm_path");
+   $ad="   authentication => {%NL%".
        "      default_realm => %SQ%users%SQ%,%NL%".
        "      realms        => {%NL%".
        "         users => {%NL%".
@@ -901,12 +973,15 @@ END
        "       login_form_args => {%NL%".
        "           authenticate_args => { active => %SQ%Y%SQ% },%NL%".
        "       },%NL%".
-       "   },%NL%".
-       ");%NL%%NL%";
+       "   },";
    ($stdout,$stderr)=$handle->cmd(
-      "${sudo}sed -i '/__PACKAGE__[-][>]setup[(][)]/i$ad' $pm_path");
-   ($stdout,$stderr)=$handle->cmd( # bash shell specific
-      "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pm_path");
+       "${sudo}sed -i '/Send X-Catalyst header/a$ad' $pm_path");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i 's/\\(^Session$\\\)/    \\1/' $pm_path");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i 's/\\(^authentication =.*\\\)/    \\1/' $pm_path");
+   ($stdout,$stderr)=$handle->cmd(
+       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pm_path");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $pm_path");
    ($stdout,$stderr)=$handle->cmd("mkdir -vp root/src/login",'__display__');
    ($stdout,$stderr)=$handle->cmd("touch root/src/login/login.tt2",
@@ -940,8 +1015,8 @@ END
 </div>
 ENDD
    ($stdout,$stderr)=$handle->cmd(
-      "echo \"$content\" > root/src/login/login.tt2");
-   ($stdout,$stderr)=$handle->cmd("mkdir -v db lib/AdventREST/Schema",
+      "echo -e \"$content\" > root/src/login/login.tt2");
+   ($stdout,$stderr)=$handle->cmd("mkdir -v db lib/FullAutoAPI/Schema",
       '__display__');
    my $db_sql="db.sql";
    $content=<<'END';
@@ -991,20 +1066,21 @@ END
    ($stdout,$stderr)=$handle->cmd("chmod -v 777 $db_sql",'__display__');
    ($stdout,$stderr)=$handle->cmd("echo \"$content\" > $db_sql");
    ($stdout,$stderr)=$handle->cmd("chmod -v 644 $db_sql",'__display__');
-   #($stdout,$stderr)=$handle->cmd('sqlite3 db/adventrest.db < db.sql');
+   #($stdout,$stderr)=$handle->cmd('sqlite3 db/fullautoapi.db < db.sql');
    ($stdout,$stderr)=$handle->cwd('db');
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".
       "http://dev.catalyst.perl.org/repos/Catalyst/trunk/".
       "examples/RestYUI/db/adventrest.db",
       '__display__');
-   ($stdout,$stderr)=$handle->cwd("../lib/AdventREST");
+   ($stdout,$stderr)=$handle->cmd("mv adventrest.db fullautoapi.db");
+   ($stdout,$stderr)=$handle->cwd("../lib/FullAutoAPI");
    $content=<<'END';
 #
-# AdventREST::Schema.pm
+# FullAutoAPI::Schema.pm
 #
  
-package AdventREST::Schema;
+package FullAutoAPI::Schema;
 use base qw/DBIx::Class::Schema/;
  
 __PACKAGE__->load_classes(qw/User/);
@@ -1016,7 +1092,7 @@ END
    ($stdout,$stderr)=$handle->cmd("echo \"$content\" > Schema.pm");
    ($stdout,$stderr)=$handle->cmd("chmod -v 644 Schema.pm",'__display__');
    $content=<<'END';
-package AdventREST::Schema::User;
+package FullAutoAPI::Schema::User;
  
 use base qw/DBIx::Class/;
 __PACKAGE__->load_components(qw/Core/);
@@ -1032,11 +1108,141 @@ END
    ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > User.pm");
    ($stdout,$stderr)=$handle->cmd("chmod -v 644 User.pm",'__display__');
    ($stdout,$stderr)=$handle->cwd("../../..");
-   ($stdout,$stderr)=$handle->cmd("./script/adventrest_create.pl ".
-      "model DB DBIC::Schema AdventREST::Schema",'__display__');
-   ($stdout,$stderr)=$handle->cmd("./script/adventrest_create.pl ".
+   ($stdout,$stderr)=$handle->cmd("./script/fullautoapi_create.pl ".
+      "model DB DBIC::Schema FullAutoAPI::Schema create=static ".
+      "components=TimeStamp,PassphraseColumn dbi:SQLite:db/fullautoapi.db",
+      '__display__');
+   my $user_path="./lib/FullAutoAPI/Schema/Result/User.pm";
+   $ad="%NL%__PACKAGE__->add_columns(%NL%".
+       "    %SQ%+password%SQ% => {%NL%".
+       "        passphrase       => %SQ%rfc2307%SQ%,%NL%".
+       "        passphrase_class => %SQ%BlowfishCrypt%SQ%,%NL%".
+       "        passphrase_args  => {%NL%".
+       "            cost        => 14,%NL%".
+       "            salt_random => 20,%NL%".
+       "        },%NL%".
+       "        passphrase_check_method => %SQ%check_password%SQ%,%NL%".
+       "    }%NL%".
+       ");";
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i '/DO NOT MODIFY THIS/a$ad' $user_path");
+   $ad="%NL%=head1 UNIQUE CONSTRAINTS,%NL%".
+       "%NL%".
+       "=head2 C<username_unique>%NL%".
+       "%NL%".
+       "=over 4%NL%".
+       "%NL%".
+       "=item * L</username>%NL%".
+       "%NL%".
+       "=back%NL%".
+       "%NL%".
+       "=cut%NL%".
+       "%NL%".
+       "__PACKAGE__->add_unique_constraint(\"username_unique\", [\"username\"]);%NL%".
+       "%NL%".
+       "=head1 RELATIONS%NL%".
+       "%NL%".
+       "=head2 user_roles%NL%".
+       "%NL%".
+       "Type: has_many%NL%".
+       "%NL%".
+       "Related object: L<MyApp::Schema::Result::UserRole>%NL%".
+       "%NL%".
+       "=cut%NL%".
+       "%NL%".
+       "__PACKAGE__->has_many(%NL%".
+       "  \"user_roles\",%NL%".
+       "  \"MyApp::Schema::Result::UserRole\",%NL%".
+       "  { \"foreign.user_id\" => \"self.id\" },%NL%".
+       "  { cascade_copy => 0, cascade_delete => 0 },%NL%".
+       ");%NL%".
+       "%NL%".
+       "=head2 roles%NL%".
+       "%NL%".
+       "Type: many_to_many%NL%".
+       "%NL%".
+       "Composing rels: L</user_roles> -> role%NL%".
+       "%NL%".
+       "=cut%NL%".
+       "%NL%".
+       "__PACKAGE__->many_to_many(\"roles\", \"user_roles\", \"role\");";
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}sed -i '/set_primary_key/a$ad' $user_path");
+   ($stdout,$stderr)=$handle->cmd( # bash shell specific
+      "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $user_path");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $user_path");
+   ($stdout,$stderr)=$handle->cmd("./script/fullautoapi_create.pl ".
       "controller OAuth2::Provider",'__display__');
-   my $pro_path="./lib/AdventREST/Controller/OAuth2/Provider.pm";
+   ($stdout,$stderr)=$handle->cmd("wget -qO- http://libevent.org/");
+   $stdout=~/^.*Stable releases.*?href=["](.*?)["].*?href=["](.*?)["].*$/s;
+   my $le_rel=$1;my $le_asc=$2;
+   ($stdout,$stderr)=$handle->cmd(
+      "wget --random-wait --progress=dot ".$le_rel,'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "wget --random-wait --progress=dot ".$le_asc,'__display__');
+   $le_rel=~s/^.*\/(.*.tar.gz)$/$1/;
+   ($stdout,$stderr)=$handle->cmd("tar xvf $le_rel",'__display__');
+   $le_rel=~s/.tar.gz$//;
+   ($stdout,$stderr)=$handle->cwd($le_rel); 
+   ($stdout,$stderr)=$handle->cmd("./configure",'__display__');
+   ($stdout,$stderr)=$handle->cmd("make",'__display__');
+   ($stdout,$stderr)=$handle->cmd("make install",'__display__');
+   ($stdout,$stderr)=$handle->cwd("..");
+   ($stdout,$stderr)=$handle->cmd("wget -qO- http://memcached.org/");
+   $stdout=~/^.*?Tar.Gz Download.*?href=["](.*?)["].*$/;
+   my $mc_rel=$1;
+   ($stdout,$stderr)=$handle->cmd(
+      "wget --random-wait --progress=dot ".$mc_rel,'__display__');
+   $mc_rel=~s/^.*\/(.*.tar.gz)$/$1/;
+   ($stdout,$stderr)=$handle->cwd($mc_rel);
+   ($stdout,$stderr)=$handle->cmd("./configure",'__display__'); 
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i 's/ -Werror//' Makefile");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "'s#struct sigaction a#// struct sigaction a#' testapp.c");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "'s#sigemptyset#// sigemptyset#' testapp.c");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "'s#sigaction(#// sigaction(#' testapp.c");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
+      "'s#{ \"cache_redzone#// { \"cache_redzone#' testapp.c");
+   ($stdout,$stderr)=$handle->cmd("make",'__display__');
+   ($stdout,$stderr)=$handle->cmd("make install",'__display__'); 
+   ($stdout,$stderr)=$handle->cwd("..");
+   #
+   # echo-ing/streaming files over ssh can be tricky. Use echo -e
+   #          and replace these characters with thier HEX
+   #          equivalents (use an external editor for quick
+   #          search and replace - and paste back results.
+   #          use copy/paste or cat file and copy/paster results.):
+   #
+   #          !  -   \\x21
+   #          "  -   \\x22
+   #          $  -   \\x24
+   #
+   $content=<<'END';
+#\\x21/usr/bin/env perl
+ 
+use strict;
+use warnings;
+use lib 'lib';
+ 
+BEGIN { \\x24ENV{CATALYST_DEBUG} = 0 }
+ 
+use MyApp;
+use DateTime;
+ 
+my \\x24admin = MyApp->model('DB::User')->search({ username => 'admin' })
+    ->single;
+ 
+\\x24admin->update({ password => 'admin', password_expires => DateTime->now });
+END
+   ($stdout,$stderr)=$handle->cmd("touch script/set_admin_password.pl");
+   ($stdout,$stderr)=$handle->cmd(
+      "chmod -v 777 script/set_admin_password.pl",
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$content\" > script/set_admin_password.pl");
+   my $pro_path="./lib/FullAutoAPI/Controller/OAuth2/Provider.pm";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
       "\"s/Catalyst::Controller/Catalyst::Controller::ActionRole/\" ".
       $pro_path);
@@ -1074,24 +1280,24 @@ END
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pro_path");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $pro_path");
    $content=<<'END';
-name: AdventREST
+name: FullAutoAPI
 Model::DB:
-    schema_class: AdventREST::Schema
+    schema_class: FullAutoAPI::Schema
     connect_info:
-        - DBI:SQLite:dbname=__path_to(db/adventrest.db)__
+        - DBI:SQLite:dbname=__path_to(db/fullautoapi.db)__
         - \\x22\\x22
         - \\x22\\x22
 END
-   ($stdout,$stderr)=$handle->cmd("touch adventrest.yml");
-   ($stdout,$stderr)=$handle->cmd("chmod -v 777 adventrest.yml",'__display__');
-   ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > adventrest.yml");
-   ($stdout,$stderr)=$handle->cmd("chmod -v 644 adventrest.yml",'__display__');
+   ($stdout,$stderr)=$handle->cmd("touch fullautoapi.yml");
+   ($stdout,$stderr)=$handle->cmd("chmod -v 777 fullautoapi.yml",'__display__');
+   ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > fullautoapi.yml");
+   ($stdout,$stderr)=$handle->cmd("chmod -v 644 fullautoapi.yml",'__display__');
    ($stdout,$stderr)=$handle->cmd(
-      "./script/adventrest_create.pl controller User",'__display__');
-   ($stdout,$stderr)=$handle->cmd("mv lib/AdventREST/Controller/User.pm ".
-      "lib/AdventREST/Controller/User.bak");
+      "./script/fullautoapi_create.pl controller User",'__display__');
+   ($stdout,$stderr)=$handle->cmd("mv lib/FullAutoAPI/Controller/User.pm ".
+      "lib/FullAutoAPI/Controller/User.bak");
    ($stdout,$stderr)=$handle->cmd(
-      "./script/adventrest_create.pl view TT TT",'__display__');
+      "./script/fullautoapi_create.pl view TT TT",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "mkdir -vp root/static/jquery",'__display__');
    ($stdout,$stderr)=$handle->cwd('root/static/jquery');
@@ -1117,7 +1323,7 @@ END
    ($stdout,$stderr)=$handle->cmd('cp -Rv resources ../..','__display__');
    ($stdout,$stderr)=$handle->cwd('../../..');
    $content=<<END;
-package AdventREST::Controller::User;
+package FullAutoAPI::Controller::User;
  
 use strict;
 use warnings;
@@ -1134,7 +1340,7 @@ use constant NBR_WORKERS    => 2;
 use constant READY          => \\x22\\\\\\\\001\\x22;
 
 use constant FRONTEND_URL   =>
-       \\x22ipc://${home_dir}AdventREST/frontend.ipc\\x22;
+       \\x22ipc://${home_dir}FullAutoAPI/frontend.ipc\\x22;
 
 BEGIN { extends 'Catalyst::Controller::REST' }
 
@@ -1307,7 +1513,7 @@ sub single_user_DELETE {
 
 1;
 END
-   ($stdout,$stderr)=$handle->cwd('lib/AdventREST/Controller');
+   ($stdout,$stderr)=$handle->cwd('lib/FullAutoAPI/Controller');
    ($stdout,$stderr)=$handle->cmd("touch User.pm");
    ($stdout,$stderr)=$handle->cmd("chmod -v 777 User.pm",'__display__');
    ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > User.pm");
@@ -1473,15 +1679,15 @@ END
       "echo \"$theswartz_schema\" | sqlite3 theschwartz.sqlt");
    ($stdout,$stderr)=$handle->cwd('..');
    ($stdout,$stderr)=$handle->cmd(
-      "./script/adventrest_create.pl model TheSchwartz",'__display__');
+      "./script/fullautoapi_create.pl model TheSchwartz",'__display__');
    $ad='__PACKAGE__->config( class => "TheSchwartz" );%NL%%NL%'. # %NL% is newline
       'sub mangle_arguments { %{ $_[1]->{args} } }%NL%';
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/Catalyst::Model/a$ad\' ".
-      "./lib/AdventREST/Model/TheSchwartz.pm");
+      "./lib/FullAutoAPI/Model/TheSchwartz.pm");
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
-      "./lib/AdventREST/Model/TheSchwartz.pm");
+      "./lib/FullAutoAPI/Model/TheSchwartz.pm");
    $content=<<END;
 Model::TheSchwartz:
   args:
@@ -1489,7 +1695,7 @@ Model::TheSchwartz:
     databases:
       - dsn: dbi:SQLite:__path_to(db/theschwartz.sqlt)__
 END
-   ($stdout,$stderr)=$handle->cmd("echo \"$content\" >> adventrest.yml");
+   ($stdout,$stderr)=$handle->cmd("echo \"$content\" >> fullautoapi.yml");
    $ad="use Net::FullAuto;%NL%".
        "use ZMQ::LibZMQ4;%NL%".
        "use ZMQ::Constants qw(:all);%NL%".
@@ -1499,9 +1705,9 @@ END
        "use constant READY          => \"\\\\001\";%NL%".
        "%NL%".
        "use constant BACKEND_URL    =>%NL%".
-       "       %SQ%ipc://${home_dir}AdventREST/backend.ipc%SQ%;%NL%".
+       "       %SQ%ipc://${home_dir}FullAutoAPI/backend.ipc%SQ%;%NL%".
        "use constant FRONTEND_URL    =>%NL%".
-       "       %SQ%ipc://${home_dir}AdventREST/frontend.ipc%SQ%;%NL%".
+       "       %SQ%ipc://${home_dir}FullAutoAPI/frontend.ipc%SQ%;%NL%".
        "%NL%".
        "use Parallel::Forker;%NL%".
        "%NL%".
@@ -1518,7 +1724,7 @@ END
        "   # A bit of custom config riding/hacking to use the application".
        "%SQ%s%NL%".
        "   # config for the DB.%NL%".
-       "   my \$config_file = %SQ%${home_dir}AdventREST/adventrest.yml".
+       "   my \$config_file = %SQ%${home_dir}FullAutoAPI/fullautoapi.yml".
        "%SQ%;%NL%".
        "   my \$config_data = YAML::LoadFile( \$config_file );%NL%".
        "   #my \$args = \$config_data->{\"Model::ZeroMQ\"}->{args};%NL%".
@@ -1697,12 +1903,12 @@ END
        "}%NL%";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/use Catalyst::ScriptRunner/i$ad\' ".
-      "./script/adventrest_server.pl");
+      "./script/fullautoapi_server.pl");
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
-      "./script/adventrest_server.pl");
+      "./script/fullautoapi_server.pl");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
-      "./script/adventrest_server.pl");
+      "./script/fullautoapi_server.pl");
    ($stdout,$stderr)=$handle->cwd("..");
    ($stdout,$stderr)=$handle->put("fullauto.pem");
    ($stdout,$stderr)=$handle->cmd(
@@ -1729,11 +1935,11 @@ END
 print "GOING TO START MYAPP SERVER\n";
    $handle->{_cmd_handle}->print(
       'script/myapp_server.pl --background');
-   ($stdout,$stderr)=$handle->cwd("../AdventREST");
+   ($stdout,$stderr)=$handle->cwd("../FullAutoAPI");
    ($stdout,$stderr)=$handle->cmd("${sudo}ldconfig");
 print "GOING TO START WEB SERVER\n";
    $handle->{_cmd_handle}->print(
-      "${sudo}script/adventrest_server.pl -p 3001 &");
+      "${sudo}script/fullautoapi_server.pl -p 3001 &");
    $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
    while (1) {
       my $output.=Net::FullAuto::FA_Core::fetch($handle);
